==> hermes_0.0.4.tar.gz: hermes-0.0.4/src/contactview.py <==
import gtk
import hildon
from ctypes import *

class ContactView(hildon.PannableArea):
  """Widget which shows a list of contacts in a pannable area.
       
     Copyright (c) Andrew Flegg <andrew@bleb.org> 2009.
     Released under the Artistic Licence."""


  # -----------------------------------------------------------------------
  def __init__(self, contacts):
    """Constructor. Passed a list of EContacts."""
    
    hildon.PannableArea.__init__(self)
    self.contacts = contacts
    self.treestore = gtk.ListStore(str, gtk.gdk.Pixbuf)
    for contact in self.contacts:
      if not contact.get_name():
        continue
        
      photo = contact.get_property('photo')
      pi = cast(c_void_p(hash(photo)), POINTER(EContactPhoto))
      pixbuf = None
      if pi.contents.data.uri.startswith("image/"):
        data = string_at(pi.contents.data.inlined.data, pi.contents.data.inlined.length)
        pixbuf_loader = gtk.gdk.PixbufLoader()
        pixbuf_loader.write(data)
        pixbuf_loader.close()
        pixbuf = pixbuf_loader.get_pixbuf()
      elif pi.contents.data.uri.startswith("file://"):
        filename = pi.contents.data.uri[7:]
        pixbuf = gtk.gdk.pixbuf_new_from_file(filename)
            
      if pixbuf:
        size = min(pixbuf.get_width(), pixbuf.get_height())
        pixbuf = pixbuf.subpixbuf(0, 0, size, size).scale_simple(48, 48, gtk.gdk.INTERP_BILINEAR)
      self.treestore.append(row = [contact.get_name(), pixbuf])

    self.treeview = gtk.TreeView(self.treestore)
    tvcolumn = gtk.TreeViewColumn('Name', gtk.CellRendererText(), text = 0)
    self.treeview.append_column(tvcolumn)

    cell = gtk.CellRendererPixbuf()
    cell.set_property('xalign', 1.0)
    tvcolumn = gtk.TreeViewColumn('Picture', cell, pixbuf = 1)
    self.treeview.append_column(tvcolumn)

    self.add(self.treeview)
    self.set_size_request(600, 380)


class EContactPhoto_inlined(Structure):
  _fields_ = [('mime_type', c_char_p),
              ('length', c_uint),
              ('data', c_void_p)]

class EContactPhoto_data(Union):
  _fields_ = [('inlined', EContactPhoto_inlined),
              ('uri', c_char_p)]

class EContactPhoto(Structure):
  _fields_ = [('type', c_int),
              ('data', EContactPhoto_data)]

==> hermes_0.1.0.tar.gz: hermes-0.1.0/src/contactview.py <==
import gtk
import hildon
from ctypes import *
from pygobject import *

class ContactView(hildon.PannableArea):
  """Widget which shows a list of contacts in a pannable area.
       
     Copyright (c) Andrew Flegg <andrew@bleb.org> 2009.
     Released under the Artistic Licence."""


  # -----------------------------------------------------------------------
  def __init__(self, contacts):
    """Constructor. Passed a list of EContacts."""
    
    hildon.PannableArea.__init__(self)
    self.contacts = contacts
    self.treestore = gtk.ListStore(str, gtk.gdk.Pixbuf)
    for contact in self.contacts:
      if not contact.get_name():
        continue
        
      photo = contact.get_property('photo')
      pi = cast(c_void_p(hash(photo)), POINTER(EContactPhoto))
      pixbuf = None
      if pi.contents.data.uri.startswith("image/"):
        data = string_at(pi.contents.data.inlined.data, pi.contents.data.inlined.length)
        pixbuf_loader = gtk.gdk.PixbufLoader()
        pixbuf_loader.write(data)
        pixbuf_loader.close()
        pixbuf = pixbuf_loader.get_pixbuf()
      elif pi.contents.data.uri.startswith("file://"):
        filename = pi.contents.data.uri[7:]
        pixbuf = gtk.gdk.pixbuf_new_from_file(filename)
            
      if pixbuf:
        size = min(pixbuf.get_width(), pixbuf.get_height())
        pixbuf = pixbuf.subpixbuf(0, 0, size, size).scale_simple(48, 48, gtk.gdk.INTERP_BILINEAR)
      self.treestore.append(row = [contact.get_name(), pixbuf])

    self.treeview = gtk.TreeView(self.treestore)
    tvcolumn = gtk.TreeViewColumn('Name', gtk.CellRendererText(), text = 0)
    self.treeview.append_column(tvcolumn)

    cell = gtk.CellRendererPixbuf()
    cell.set_property('xalign', 1.0)
    tvcolumn = gtk.TreeViewColumn('Picture', cell, pixbuf = 1)
    self.treeview.append_column(tvcolumn)

    self.add(self.treeview)
    self.set_size_request(600, 380)
